    
          ParticleData
          ============

The ParticleData file contains four classes:
* ParticleDataEntry, which stores the relevant information on a 
    particle species, and
* ParticleDataTable, which is a map of PDG particle id numbers [1]
    onto the relevant ParticleDataEntry. 
* DecayChannel, which stores info on one particular decay mode.
* DecayTable, which is a vector of DecayChannel's, containing all
    the decay modes of a particle, and also methods for picking
    a decay mode.
These files together form a database that is continuously being used 
as the program has to assign particle masses, decay modes etc.

The ParticleDataTable class is purely static, i.e. you can interact
with it directly by ParticleDataTable::command(argument). However, 
a particleData object of the ParticleDataTable class is a public 
member of the Pythia class, so an alternative notation would be 
pythia.particleData.command(argument), assuming that pythia is an 
instance of the Pythia class. Further, for some of the most 
frequent user tasks, Pythia methods have been defined, so that 
pythia.command(argument) would work, see further below.

A fundamental difference between the ParticleData classes and the 
Settings ones is that the former are accessed regularly during the 
event generation process, as a new particle is produced and its mass 
need to be set, e.g., while Settings is mainly/only used at the 
initialization stage. Nevertheless, it is not a good idea to change 
data in either of them in mid-run, since this may lead to 
inconsistencies. 

---------------------------------------------------------------------- 

   Stored properties
   -----------------

Currently the following particle properties are stored in the
ParticleDataTable for a given PDG particle identity code id, 
here presented by the name used to access this property: 
- hasAnti(id) : bool whether a distinct antiparticle exists or not;
- name(id) : particle and antiparticle names are stored separately,
    the sign of id determines which of the two is returned, with
    "void" used to indicate the absence of an antiparticle; 
- charge3(id) three times the charge (to make it an integer),
  alternatively charge(id), which is a double equal to charge3(id)/3.;
- colType(id) : the colour type, with 0 uncoloured, 1 triplet, 
    -1 antitriplet and 2 octet;
- m0(id) : the nominal mass m_0 (in GeV);
- constituentMass(id) : is the constituent mass for a quark, 
    hardcoded as m_u = m_d = 0.325, m_s = 0.50, m_c = 1.60 and 
    m_b = 5.0 GeV, for a diquark the sum of quark constituent masses,
    and for everything else the same as the ordinary mass
- width(id) the width Gamma of the Breit-Wigner distribution (in GeV);
- range(id) : the allowed mass range generated by the Breit-Wigner,
    | m - m_0 | < range (in GeV);
- tau0(id) : the nominal proper lifetime tau_0 (in mm/c); 
- mayDecay(id) : a flag telling whether a particle species may decay 
    or not, offering the main user switch (whether a given particle 
    of this kind then actually will decay also depends on other flags 
    in the ParticleDecays class).
- externalDecay(id) : a flag telling whether a particle should be 
    handled by an external decay package or not, with the latter
    default. Can be changed when pythia.decayPtr is called, but should 
    not be modified otherwise. 
Similar methods can also be used to set these properties.

There are three further methods for output:
- particleDataPtr(id) returns a pointer to the ParticleDataEntry 
    object;
- mass(id) : returns a mass distributed according to a truncated
    Breit-Wigner, with parameters as above (see also the
    ParticleData:modeBreitWigner switch below);
- spin(id) : 2 * s + 1 where known, else 0.

The following properties are stored for each decay channel:
- branchingRatio() : the branching ratio;
- modeME() : the mode of processing this channel, possibly with 
    matrix elements (see below);
- multiplicity(): the number of decay products in a channel, at most 8;
- product(i) : a list of the decay products, 8 products 0 <= i < 8,
    with trailing unused ones set to 0.

The decay table also defines a few methods:
- addChannel( branchingRatio, modeME, product1, ...) adds a decay
    channel with up to 8 products.
- size() : gives the number of decay channels for a particle;
- pick() : picks one decay channel according to their respective
    branching ratios;
- rescaleBR() : rescale all branching ratios to unit sum. 
 
---------------------------------------------------------------------- 

   Operation
   ---------

The normal flow of the particle data operations is:

1) When a Pythia object "pythia" is created, the ParticleDataTable
member pythia.particleData is asked to scan the current file, i.e.
ParticleData.man. 

2) All lines beginning with <particle> are scanned for information on a
particle species, and all lines beginning with <channel> are assumed to
contain a decay channel of the most recent particle.
The information stored in a <particle> line is: id, name, antiparticle 
name, 3*charge, colour type, nominal mass, width, range, nominal proper
lifetime, and whether the particle may decay.
The information stored in a <channel> is: branching ratio, mode, and 
decay products.   
IMPORTANT: the values in the .man file should not be changed, except
by the Pythia author. Any changes should be done with the help of
the methods described below.

3) Between the creation of the Pythia object and the "init" call for 
it, you may use the methods of the ParticleDataTable class to modify 
some of the default values. Several different approaches can be chosen 
for this.
 
3a) Inside your main program you can directly set values with
    pythia.particleData.readString(string)
where both the variable name and the value are contained inside
the character string, separated by blanks and/or a =, e.g. 
    pythia.particleData.readString("Particle:111:mayDecay = off"); 
switches off the decays of the pi0.
    
The first part, "Particle:", is optional, as is the equal sign. The 
particle id (> 0) and the property to be changed must be given, 
separated by a colon. 

The allowed properties are: name, antiName, names (in which case the 
input consists of both the particle and the antiparticle name, 
separated by a blank), charge3, colType, m0, width, range, tau0 and 
mayDecay. All of these names are case-insensitive. Names that do not 
match an existing variable are ignored. A warning is printed, however, 
unless an optional second argument "false" is used. Values below the 
minimum or above the maximum are set at the respective border. For bool 
values, the following notation may be used interchangeably: 
true = on = yes = ok = 1, while everything else gives false (including 
but not limited to false, off, no and 0). 

Alternatively the id code may be followed by another integer, which 
then gives the decay channel number, which has to be followed by the 
property specific to this channel, either branchingRatio, rescaleBR, 
modeME or products. In the latter case all the products of the channel 
should be given, separated by blanks, with scan ending at the first 
non-digit, including end of line. 

The Pythia class contains a readString method that hand on to this
method, or to corresponding methods in Settings or Pythia6,
and therefore may offer the most convenient form, i.e. more compactly:
    pythia.readString("111:mayDecay = off"); 
    pythia.readString("15:2:products = 16 -211"); 

In addition to the format outlined above, a second format is available,
which is identical with the one used in the data tables at the end of 
this file. Thus a new particle can be defined, or an old one redefined,
by a string beginning with <particle>, and subsequent lines beginning
with <channel> define new decay channels for this particle. The formats
for such strings are of the character
#<particle>  id  name  antiname(or void)  charge3  colType  
            m0  width  range  tau0  mayDecay  
#<channel>  branchingRatio  modeME  products 
(the # is added here to avoid parsing errors when reading this file).

3b) Underlying this are commands for all the individual properties in  
the ParticleDataTable class, one for each. Thus, an example now reads 
    pythia.particleData.mayDecay(111, false);
Bool values should here be given as true or false. 

3c) A simpler and more useful way is to collect all your changes
in a separate file, with one line per change, e.g. 
    Particle:111:mayDecay = off
Each line is process as described for the string in 3a). Since names 
that do not match an existing variable are ignored, you can easily 
comment out lines. The recommended way would be to add a special 
character like # or ! in the first column, but avoid < since this 
clashes with the use of <particle> and <channel> as tags.

The file can be read by the 
    pythia.particleData.readFile("filename") 
method, alternatively by the 
    pythia.readFile("filename") 
method. The latter has the advantage that it allows you to freely mix 
commands to the Settings, ParticleData and Pythia6 classes, and so 
is preferable.

4) In the Pythia "init" call, many of the various other program  
elements are initialized, making use of the values in the database.
During the run the database will be heavily used. It is therefore 
dangerous to do further changes in mid-run. 

A routine reInit("filename") is provided, and can be used to zero the
particle data table and reinitialize  from scratch. Such a call might 
be required if several Pythia objects are created in the same run, and 
requested to have different values - by default the init() call is 
only made the first time. Several pythia with different values would 
have to run sequentially and not in parallel, though; recall that there 
is only one instance of the particle data table.

5) You may at any time obtain a listing of the particle data by calling
    pythia.particleData.list();
The listing is by increasing id number. To list only one particle,
give its id code as argument. To list a restricted set of particles,
give in their id codes as a vector<int>.

---------------------------------------------------------------------- 
 
   Main parameters
   ---------------

<mode> ParticleData:modeBreitWigner = 1 min = 0 max = 2
Selection of particle masses:
0: mass is fixed at the nominal m_0 value.
1: particles registered as having a mass width are given a mass according
    to a truncated Breit-Wigner | m - m_0 | < range, linear in m.
2: as 1, but quadratic in m instead of linear.

---------------------------------------------------------------------- 
 
   Modes for Matrix Element Processing
   -----------------------------------

The list of allowed decay mode codes, accessed by modeME() above, almost 
agrees with the Pythia 6 ones, but several obsolete have been removed, 
and a few moved for better consistency. Here is the list of currently 
allowed codes:
  0 : pure phace space of produced particles ("default")
  1 : omega and phi -> pi+ pi- pi0
  2 : Dalitz decay of pi0 and eta
  3 : polarization in V -> PS + PS (V = vector, PS = pseudoscalar), 
      when V is produced by PS -> PS + V or PS -> gamma + V
 11 : turn partons into hadrons and distribute in pure phase space  
 12 : ditto, but with higher average multiplicity (imagined q -> g)
 13 - 15 : as 11, but require at least code - 10 number of particles
      in the decay channel
 22 - 30 : as 11, but fixed multiplicity code - 20
 32 : decay to q qbar or g g, which should shower and hadronize
 33 (was 4) : decay onium to g g g or g g gamma (with matrix element),
      which should shower and hadronize
 41 : decay to phase space, but weight up neutrino_tau spectrum
      in tau decay
 42 : weak decay; if there is a quark spectator system it collapses to 
      one hadron; for leptonic/semileptonic decays the V-A matrix element
      is used, for hadronic decays simple phase space (gives somewhat
      softer B -> D spectrum than Pythia 6.3; to be improved!??)
 43 (was 48) : as 42, but require at least three particles in decay
   
---------------------------------------------------------------------- 

References

[1] Particle Data Group, S. Eidelman et al., 
    Phys. Lett. B592 (2004) 1

---------------------------------------------------------------------- 
 
   The data itself
   ---------------

 <particle>        1  d                 dbar             -1  1     0.33000     0.00000     0.00000  0.00000E+00  0
 <particle>        2  u                 ubar              2  1     0.33000     0.00000     0.00000  0.00000E+00  0
 <particle>        3  s                 sbar             -1  1     0.50000     0.00000     0.00000  0.00000E+00  0
 <particle>        4  c                 cbar              2  1     1.50000     0.00000     0.00000  0.00000E+00  0
 <particle>        5  b                 bbar             -1  1     4.80000     0.00000     0.00000  0.00000E+00  0
 <particle>        6  t                 tbar              2  1   175.00000     1.39816    13.98156  0.00000E+00  1
 <particle>        7  b'                b'bar            -1  1   400.00000     0.00000     0.00000  0.00000E+00  1
 <particle>        8  t'                t'bar             2  1   400.00000     0.00000     0.00000  0.00000E+00  1
 <particle>       11  e-                e+               -3  0     0.00051     0.00000     0.00000  0.00000E+00  0
 <particle>       12  nu_e              nu_ebar           0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       13  mu-               mu+              -3  0     0.10566     0.00000     0.00000  6.58654E+05  0
 <channel>   1.0000000   42      -12       11       14
 <particle>       14  nu_mu             nu_mubar          0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       15  tau-              tau+             -3  0     1.77700     0.00000     0.00000  8.72000E-02  1
 <channel>   0.1783000   42      -12       11       16
 <channel>   0.1735000   42      -14       13       16
 <channel>   0.1131000    0       16     -211
 <channel>   0.2494000    0       16     -213
 <channel>   0.0030000   41       16     -211      111
 <channel>   0.0900000   41       16     -213      111
 <channel>   0.0027000   41       16     -211      111      111
 <channel>   0.0100000   41       16     -213      111      111
 <channel>   0.0014000   41       16     -211      111      111      111
 <channel>   0.0012000   41       16     -213      111      111      111
 <channel>   0.0002500   41       16     -211      310
 <channel>   0.0002500   41       16     -211      130
 <channel>   0.0071000    0       16     -321
 <channel>   0.0120000    0       16     -323
 <channel>   0.0004000   41       16     -321      111
 <channel>   0.0007500   41       16     -323      111
 <channel>   0.0000600   41       16     -323      111      111
 <channel>   0.0007800   41       16     -321      310
 <channel>   0.0007800   41       16     -321      130
 <channel>   0.0034000   41       16     -321      321     -211
 <channel>   0.0800000   41       16     -211      113
 <channel>   0.0110000   41       16     -211      211     -211
 <channel>   0.0191000   41       16     -211      223
 <channel>   0.0000600   41       16     -211      221
 <channel>   0.0050000   41       16     -213      113
 <channel>   0.0133000   41       16     -211      113      111
 <channel>   0.0067000   41       16     -213      211     -211
 <channel>   0.0005000   41       16     -211      211     -211      111
 <channel>   0.0035000   41       16     -213      223
 <channel>   0.0006000   41       16     -211      223      111
 <channel>   0.0015000   41       16     -213      221
 <channel>   0.0002100   41       16     -211      221      111
 <channel>   0.0002000   41       16     -213      113      111
 <channel>   0.0007500   41       16     -211      113      113
 <channel>   0.0001000   41       16     -211      221      221
 <channel>   0.0002000   41       16     -211      113      111      111
 <channel>   0.0011000   41       16     -213      113      111      111
 <channel>   0.0002000   41       16     -211      213     -213
 <channel>   0.0002000   41       16     -211      213     -211      111
 <channel>   0.0002000   41       16     -211     -213      211      111
 <channel>   0.0002200   41       16     -211      113      113      111
 <channel>   0.0004000   41       16     -323      111      111
 <channel>   0.0001000   41       16     -321      111      111      111
 <channel>   0.0020500   41       16     -211      310      111
 <channel>   0.0020500   41       16     -211      130      111
 <channel>   0.0006900   41       16     -321      310      111
 <channel>   0.0006900   41       16     -321      130      111
 <channel>   0.0002500   41       16     -211      310      310
 <channel>   0.0005100   41       16     -211      310      130
 <channel>   0.0002500   41       16     -211      130      130
 <particle>       16  nu_tau            nu_taubar         0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       17  tau'-             tau'+            -3  0   400.00000     0.00000     0.00000  0.00000E+00  1
 <particle>       18  nu'_tau           nu'_taubar        0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       21  g                 void              0  2     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       22  gamma             void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       23  Z0                void              0  0    91.18800     2.47813    24.78129  0.00000E+00  1
 <particle>       24  W+                W-                3  0    80.45000     2.07115    20.71149  0.00000E+00  1
 <particle>       25  h0                void              0  0   115.00000     0.00367     0.03669  0.00000E+00  1
 <particle>       32  Z'0               void              0  0   500.00000    14.54029   145.40294  0.00000E+00  1
 <particle>       33  Z"0               void              0  0   900.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       34  W'+               W'-               3  0   500.00000    16.66099   166.60993  0.00000E+00  1
 <particle>       35  H0                void              0  0   300.00000     8.38842    83.88423  0.00000E+00  1
 <particle>       36  A0                void              0  0   300.00000     3.37520    33.75195  0.00000E+00  1
 <particle>       37  H+                H-                3  0   300.00000     4.17669    41.76694  0.00000E+00  1
 <particle>       39  Graviton          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       41  R0                Rbar0             0  0  5000.00000   417.29147  4172.91467  0.00000E+00  1
 <particle>       42  LQ_ue             LQ_uebar         -1  1   200.00000     0.39162     3.91621  0.00000E+00  1
 <particle>       81  specflav          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       82  rndmflav          rndmflavbar       0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       88  junction          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       90  system            void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       91  cluster           void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       92  string            void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       93  indep.            void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       94  CMshower          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       95  SPHEaxis          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       96  THRUaxis          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       97  CLUSjet           void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       98  CELLjet           void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>       99  table             void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>      110  reggeon           void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>      111  pi0               void              0  0     0.13498     0.00000     0.00000  3.00000E-05  1
 <channel>   0.9880000    0       22       22
 <channel>   0.0120000    2       22       11      -11
 <particle>      113  rho0              void              0  0     0.76850     0.15100     0.40000  0.00000E+00  1
 <channel>   0.9987390    3      211     -211
 <channel>   0.0007900    0      111       22
 <channel>   0.0003800    0      221       22
 <channel>   0.0000460    0       13      -13
 <channel>   0.0000450    0       11      -11
 <particle>      115  a_20              void              0  0     1.31800     0.10700     0.25000  0.00000E+00  1
 <channel>   0.3472500    0      213     -211
 <channel>   0.3472500    0     -213      211
 <channel>   0.1440000    0      221      111
 <channel>   0.1040000    0      223      211     -211
 <channel>   0.0245000    0      321     -321
 <channel>   0.0122500    0      130      130
 <channel>   0.0122500    0      310      310
 <channel>   0.0028000    0      111       22
 <channel>   0.0057000    0      331      111
 <particle>      130  K_L0              void              0  0     0.49767     0.00000     0.00000  1.55000E+04  0
 <channel>   0.2112000    0      111      111      111
 <channel>   0.1256000    0      211     -211      111
 <channel>   0.1939000   42      -12       11      211
 <channel>   0.1939000   42       12      -11     -211
 <channel>   0.1359000   42      -14       13      211
 <channel>   0.1359000   42       14      -13     -211
 <channel>   0.0020000    0      211     -211
 <channel>   0.0010000    0      111      111
 <channel>   0.0006000    0       22       22
 <particle>      211  pi+               pi-               3  0     0.13957     0.00000     0.00000  7.80450E+03  0
 <channel>   0.9998770    0      -13       14
 <channel>   0.0001230    0      -11       12
 <particle>      213  rho+              rho-              3  0     0.76690     0.14900     0.40000  0.00000E+00  1
 <channel>   0.9995500    3      211      111
 <channel>   0.0004500    0      211       22
 <particle>      215  a_2+              a_2-              3  0     1.31800     0.10700     0.25000  0.00000E+00  1
 <channel>   0.3472500    0      213      111
 <channel>   0.3472500    0      113      211
 <channel>   0.1440000    0      221      211
 <channel>   0.1040000    0      223      211      111
 <channel>   0.0490000    0      321     -311
 <channel>   0.0028000    0      211       22
 <channel>   0.0057000    0      331      211
 <particle>      221  eta               void              0  0     0.54745     0.00000     0.00000  0.00000E+00  1
 <channel>   0.3923000    0       22       22
 <channel>   0.3210000    0      111      111      111
 <channel>   0.2317000    0      211     -211      111
 <channel>   0.0478000    0       22      211     -211
 <channel>   0.0049000    2       22       11      -11
 <channel>   0.0013000    0      211     -211       11      -11
 <channel>   0.0003000    0       22       13      -13
 <channel>   0.0007000    0      111       22       22
 <particle>      223  omega             void              0  0     0.78194     0.00843     0.10000  0.00000E+00  1
 <channel>   0.8900000    1      211     -211      111
 <channel>   0.0869300    0       22      111
 <channel>   0.0221000    3      211     -211
 <channel>   0.0008300    0      221       22
 <channel>   0.0000700    0      111      111       22
 <channel>   0.0000700    0       11      -11
 <particle>      225  f_2               void              0  0     1.27500     0.18500     0.17000  0.00000E+00  1
 <channel>   0.5640000    0      211     -211
 <channel>   0.2820000    0      111      111
 <channel>   0.0720000    0      211     -211      111      111
 <channel>   0.0280000    0      211     -211      211     -211
 <channel>   0.0230000    0      321     -321
 <channel>   0.0115000    0      130      130
 <channel>   0.0115000    0      310      310
 <channel>   0.0050000    0      221      221
 <channel>   0.0030000    0      111      111      111      111
 <particle>      310  K_S0              void              0  0     0.49767     0.00000     0.00000  2.67620E+01  1
 <channel>   0.6861000    0      211     -211
 <channel>   0.3139000    0      111      111
 <particle>      311  K0                Kbar0             0  0     0.49767     0.00000     0.00000  0.00000E+00  1
 <channel>   0.5000000    0      130
 <channel>   0.5000000    0      310
 <particle>      313  K*0               K*bar0            0  0     0.89610     0.05050     0.20000  0.00000E+00  1
 <channel>   0.6650000    3      321     -211
 <channel>   0.3330000    3      311      111
 <channel>   0.0020000    0      311       22
 <particle>      315  K*_20             K*_2bar0          0  0     1.43200     0.10900     0.12000  0.00000E+00  1
 <channel>   0.3330000    0      321     -211
 <channel>   0.1660000    0      311      111
 <channel>   0.1680000    0      323     -211
 <channel>   0.0840000    0      313      111
 <channel>   0.0870000    0      323     -211      111
 <channel>   0.0430000    0      313      211     -211
 <channel>   0.0590000    0      321     -213
 <channel>   0.0290000    0      311      113
 <channel>   0.0290000    0      311      223
 <channel>   0.0020000    0      311      221
 <particle>      321  K+                K-                3  0     0.49360     0.00000     0.00000  3.70900E+03  0
 <channel>   0.6352000    0      -13       14
 <channel>   0.2116000    0      211      111
 <channel>   0.0559000    0      211      211     -211
 <channel>   0.0173000    0      211      111      111
 <channel>   0.0482000   42       12      -11      111
 <channel>   0.0318000   42       14      -13      111
 <particle>      323  K*+               K*-               3  0     0.89160     0.04980     0.20000  0.00000E+00  1
 <channel>   0.6660000    3      311      211
 <channel>   0.3330000    3      321      111
 <channel>   0.0010000    0      321       22
 <particle>      325  K*_2+             K*_2-             3  0     1.42500     0.09800     0.12000  0.00000E+00  1
 <channel>   0.3320000    0      311      211
 <channel>   0.1660000    0      321      111
 <channel>   0.1680000    0      313      211
 <channel>   0.0840000    0      323      111
 <channel>   0.0860000    0      313      211      111
 <channel>   0.0430000    0      323      211     -211
 <channel>   0.0590000    0      311      213
 <channel>   0.0290000    0      321      113
 <channel>   0.0290000    0      321      223
 <channel>   0.0020000    0      321      221
 <channel>   0.0020000    0      321       22
 <particle>      331  eta'              void              0  0     0.95777     0.00020     0.00200  0.00000E+00  1
 <channel>   0.4370000    0      211     -211      221
 <channel>   0.2080000    0      111      111      221
 <channel>   0.3020000    0       22      113
 <channel>   0.0302000    0       22      223
 <channel>   0.0212000    0       22       22
 <channel>   0.0016000    0      111      111      111
 <particle>      333  phi               void              0  0     1.01940     0.00443     0.01500  0.00000E+00  1
 <channel>   0.4894700    3      321     -321
 <channel>   0.3400000    3      130      310
 <channel>   0.0430000    0     -213      211
 <channel>   0.0430000    0      113      111
 <channel>   0.0430000    0      213     -211
 <channel>   0.0270000    1      211     -211      111
 <channel>   0.0126000    0       22      221
 <channel>   0.0013000    0      111       22
 <channel>   0.0003000    0       11      -11
 <channel>   0.0002500    0       13      -13
 <channel>   0.0000800    0      211     -211
 <particle>      335  f'_2              void              0  0     1.52500     0.07600     0.20000  0.00000E+00  1
 <channel>   0.4440000    0      321     -321
 <channel>   0.2220000    0      130      130
 <channel>   0.2220000    0      310      310
 <channel>   0.1040000    0      221      221
 <channel>   0.0040000    0      211     -211
 <channel>   0.0040000    0      111      111
 <particle>      411  D+                D-                3  0     1.86930     0.00000     0.00000  3.17000E-01  1
 <channel>   0.0700000   42      -11       12     -311
 <channel>   0.0650000   42      -11       12     -313
 <channel>   0.0050000   42      -11       12     -311      111
 <channel>   0.0050000   42      -11       12     -321      211
 <channel>   0.0110000   42      -11       12     -313      111
 <channel>   0.0110000   42      -11       12     -323      211
 <channel>   0.0010000   42      -11       12      111
 <channel>   0.0010000   42      -11       12      221
 <channel>   0.0010000   42      -11       12      331
 <channel>   0.0010000   42      -11       12      113
 <channel>   0.0010000   42      -11       12      223
 <channel>   0.0700000   42      -13       14     -311
 <channel>   0.0650000   42      -13       14     -313
 <channel>   0.0050000   42      -13       14     -311      111
 <channel>   0.0050000   42      -13       14     -321      211
 <channel>   0.0110000   42      -13       14     -313      111
 <channel>   0.0110000   42      -13       14     -323      211
 <channel>   0.0010000   42      -13       14      111
 <channel>   0.0010000   42      -13       14      221
 <channel>   0.0010000   42      -13       14      331
 <channel>   0.0010000   42      -13       14      113
 <channel>   0.0010000   42      -13       14      223
 <channel>   0.0260000    0     -311      211
 <channel>   0.0190000    0     -313      211
 <channel>   0.0660000    0     -311      213
 <channel>   0.0410000    0     -313      213
 <channel>   0.0450000    0   -20313      211
 <channel>   0.0760000    0     -311    20213
 <channel>   0.0073000    0     -311      321
 <channel>   0.0047000    0     -313      321
 <channel>   0.0047000    0     -311      323
 <channel>   0.0260000    0     -313      323
 <channel>   0.0010000    0      111      211
 <channel>   0.0006000    0      111      213
 <channel>   0.0066000    0      221      211
 <channel>   0.0050000    0      221      213
 <channel>   0.0030000    0      331      211
 <channel>   0.0030000    0      331      213
 <channel>   0.0006000    0      113      211
 <channel>   0.0006000    0      113      213
 <channel>   0.0010000    0      223      211
 <channel>   0.0010000    0      223      213
 <channel>   0.0060000    0      333      211
 <channel>   0.0050000    0      333      213
 <channel>   0.0120000    0     -311      211      111
 <channel>   0.0057000    0     -313      211      113
 <channel>   0.0670000    0     -321      211      211
 <channel>   0.0080000    0     -321      213      211
 <channel>   0.0022000    0      211      211     -211
 <channel>   0.0270000    0     -311      321     -311
 <channel>   0.0040000    0     -321      321      211
 <channel>   0.0190000    0      333      211      111
 <channel>   0.0120000    0     -311      211      211     -211
 <channel>   0.0020000    0     -313      211      211     -211
 <channel>   0.0090000    0     -321      211      211      111
 <channel>   0.0218000    0      211      211     -211      111
 <channel>   0.0010000    0     -321      211      211      211     -211
 <channel>   0.0220000    0     -321      211      211      111      111
 <channel>   0.0870000    0     -311      211      211     -211      111
 <channel>   0.0010000    0     -311      113      211      211     -211
 <channel>   0.0019000    0     -321      113      211      211      111
 <channel>   0.0015000    0      211      211      211     -211     -211
 <channel>   0.0028000    0      113      211      211     -211      111
 <particle>      413  D*+               D*-               3  0     2.01000     0.00000     0.00000  0.00000E+00  1
 <channel>   0.6830000    3      421      211
 <channel>   0.3060000    3      411      111
 <channel>   0.0110000    0      411       22
 <particle>      415  D*_2+             D*_2-             3  0     2.46000     0.02300     0.12000  0.00000E+00  1
 <channel>   0.3000000    0      421      211
 <channel>   0.1500000    0      411      111
 <channel>   0.1600000    0      423      211
 <channel>   0.0800000    0      413      111
 <channel>   0.1300000    0      423      211      111
 <channel>   0.0600000    0      413      211     -211
 <channel>   0.0800000    0      421      211      111
 <channel>   0.0400000    0      411      211     -211
 <particle>      421  D0                Dbar0             0  0     1.86450     0.00000     0.00000  1.24400E-01  1
 <channel>   0.0340000   42      -11       12     -321
 <channel>   0.0270000   42      -11       12     -323
 <channel>   0.0020000   42      -11       12     -311     -211
 <channel>   0.0020000   42      -11       12     -321      111
 <channel>   0.0040000   42      -11       12     -313     -211
 <channel>   0.0040000   42      -11       12     -323      111
 <channel>   0.0020000   42      -11       12     -211
 <channel>   0.0020000   42      -11       12     -213
 <channel>   0.0340000   42      -13       14     -321
 <channel>   0.0270000   42      -13       14     -323
 <channel>   0.0020000   42      -13       14     -311     -211
 <channel>   0.0020000   42      -13       14     -321      111
 <channel>   0.0040000   42      -13       14     -313     -211
 <channel>   0.0040000   42      -13       14     -323      111
 <channel>   0.0020000   42      -13       14     -211
 <channel>   0.0020000   42      -13       14     -213
 <channel>   0.0365000    0     -321      211
 <channel>   0.0450000    0     -323      211
 <channel>   0.0730000    0     -321      213
 <channel>   0.0620000    0     -323      213
 <channel>   0.0210000    0     -311      111
 <channel>   0.0210000    0     -313      111
 <channel>   0.0210000    0     -313      221
 <channel>   0.0061000    0     -311      113
 <channel>   0.0150000    0     -313      113
 <channel>   0.0250000    0     -311      223
 <channel>   0.0088000    0     -311      333
 <channel>   0.0740000    0     -321    20213
 <channel>   0.0109000    0   -10323      211
 <channel>   0.0041000    0     -321      321
 <channel>   0.0020000    0     -323      321
 <channel>   0.0035000    0     -321      323
 <channel>   0.0011000    0     -311      311
 <channel>   0.0010000    0     -313      311
 <channel>   0.0027000    0     -313      313
 <channel>   0.0016000    0      211     -211
 <channel>   0.0016000    0      111      111
 <channel>   0.0018000    0      333      113
 <channel>   0.0110000    0     -321      211      111
 <channel>   0.0063000    0     -321      211      113
 <channel>   0.0052000    0     -321      321     -311
 <channel>   0.0180000    0     -311      211     -211
 <channel>   0.0160000    0     -313      211     -211
 <channel>   0.0034000    0     -321      311      211
 <channel>   0.0036000    0     -313      321     -211
 <channel>   0.0009000    0      310      310      310
 <channel>   0.0006000    0      333      211     -211
 <channel>   0.0150000    0      211     -211      111
 <channel>   0.0923000    0     -321      211      111      111
 <channel>   0.0180000    0     -321      211      211     -211
 <channel>   0.0220000    0     -311      211     -211      111
 <channel>   0.0077000    0     -313      211     -211      111
 <channel>   0.0090000    0     -311      321     -321      111
 <channel>   0.0075000    0      211      211     -211     -211
 <channel>   0.0240000    0     -321      211      211     -211      111
 <channel>   0.0085000    0     -311      211      211     -211     -211
 <channel>   0.0670000    0     -311      211     -211      111      111
 <channel>   0.0511000    0     -311      113      111      111      111
 <channel>   0.0170000    0      211      211     -211     -211      111
 <channel>   0.0004000    0      113      211      211     -211     -211
 <channel>   0.0028000    0      321     -321      211     -211      111
 <particle>      423  D*0               D*bar0            0  0     2.00670     0.00000     0.00000  0.00000E+00  1
 <channel>   0.6190000    3      421      111
 <channel>   0.3810000    0      421       22
 <particle>      425  D*_20             D*_2bar0          0  0     2.46000     0.02300     0.12000  0.00000E+00  1
 <channel>   0.3000000    0      411     -211
 <channel>   0.1500000    0      421      111
 <channel>   0.1600000    0      413     -211
 <channel>   0.0800000    0      423      111
 <channel>   0.1300000    0      413     -211      111
 <channel>   0.0600000    0      423      211     -211
 <channel>   0.0800000    0      411     -211      111
 <channel>   0.0400000    0      421      211     -211
 <particle>      431  D_s+              D_s-              3  0     1.96850     0.00000     0.00000  1.40000E-01  1
 <channel>   0.0100000    0      -15       16
 <channel>   0.0200000   42      -11       12      221
 <channel>   0.0200000   42      -11       12      331
 <channel>   0.0300000   42      -11       12      333
 <channel>   0.0050000   42      -11       12      321     -321
 <channel>   0.0050000   42      -11       12      311     -311
 <channel>   0.0200000   42      -13       14      221
 <channel>   0.0200000   42      -13       14      331
 <channel>   0.0300000   42      -13       14      333
 <channel>   0.0050000   42      -13       14      321     -321
 <channel>   0.0050000   42      -13       14      311     -311
 <channel>   0.0150000    0      221      211
 <channel>   0.0370000    0      331      211
 <channel>   0.0280000    0      333      211
 <channel>   0.0790000    0      221      213
 <channel>   0.0950000    0      331      213
 <channel>   0.0520000    0      333      213
 <channel>   0.0078000    0    10221      211
 <channel>   0.0010000    0      211      111
 <channel>   0.0010000    0      213      111
 <channel>   0.0010000    0      211      113
 <channel>   0.0010000    0      213      113
 <channel>   0.0280000    0      321     -311
 <channel>   0.0330000    0      323     -311
 <channel>   0.0260000    0      321     -313
 <channel>   0.0500000    0      323     -313
 <channel>   0.0100000    0     2212    -2112
 <channel>   0.0050000    0      221      321
 <channel>   0.0050000    0      331      321
 <channel>   0.0050000    0      333      321
 <channel>   0.0050000    0      221      323
 <channel>   0.2500000   13        2       -1        3       -3
 <channel>   0.0952000   13        2       -1
 <particle>      433  D*_s+             D*_s-             3  0     2.11240     0.00000     0.00000  0.00000E+00  1
 <channel>   0.9400000    0      431       22
 <channel>   0.0600000    0      431      111
 <particle>      435  D*_2s+            D*_2s-            3  0     2.57350     0.01500     0.05000  0.00000E+00  1
 <channel>   0.4000000    0      421      321
 <channel>   0.4000000    0      411      311
 <channel>   0.1000000    0      423      321
 <channel>   0.1000000    0      413      311
 <particle>      441  eta_c             void              0  0     2.97980     0.00130     0.00500  0.00000E+00  1
 <channel>   1.0000000   12       82      -82
 <particle>      443  J/psi             void              0  0     3.09688     0.00000     0.00000  0.00000E+00  1
 <channel>   0.0602000    0       11      -11
 <channel>   0.0601000    0       13      -13
 <channel>   0.8797000   12       82      -82
 <particle>      445  chi_2c            void              0  0     3.55620     0.00200     0.01000  0.00000E+00  1
 <channel>   0.1350000    0      443       22
 <channel>   0.8650000   12       82      -82
 <particle>      511  B0                Bbar0             0  0     5.27920     0.00000     0.00000  4.68000E-01  1
 <channel>   0.0200000   42       12      -11     -411
 <channel>   0.0550000   42       12      -11     -413
 <channel>   0.0050000   42       12      -11   -10413
 <channel>   0.0050000   42       12      -11   -10411
 <channel>   0.0080000   42       12      -11   -20413
 <channel>   0.0120000   42       12      -11     -415
 <channel>   0.0200000   42       14      -13     -411
 <channel>   0.0550000   42       14      -13     -413
 <channel>   0.0050000   42       14      -13   -10413
 <channel>   0.0050000   42       14      -13   -10411
 <channel>   0.0080000   42       14      -13   -20413
 <channel>   0.0120000   42       14      -13     -415
 <channel>   0.0100000   42       16      -15     -411
 <channel>   0.0300000   42       16      -15     -413
 <channel>   0.0035000    0     -411      211
 <channel>   0.0110000    0     -411      213
 <channel>   0.0055000    0     -411    20213
 <channel>   0.0042000    0     -413      211
 <channel>   0.0090000    0     -413      213
 <channel>   0.0180000    0     -413    20213
 <channel>   0.0150000    0     -411      431
 <channel>   0.0185000    0     -411      433
 <channel>   0.0135000    0     -413      431
 <channel>   0.0250000    0     -413      433
 <channel>   0.0004000    0      441      311
 <channel>   0.0007000    0      441      313
 <channel>   0.0008000    0      443      311
 <channel>   0.0014000    0      443      313
 <channel>   0.0019000    0    20443      311
 <channel>   0.0025000    0    20443      313
 <channel>   0.4291000   43        2       -1       -4        1
 <channel>   0.0800000   13        2       -4       -1        1
 <channel>   0.0700000   13        4       -3       -4        1
 <channel>   0.0200000   13        4       -4       -3        1
 <channel>   0.0150000   42        2       -1       -2        1
 <channel>   0.0050000   42        4       -3       -2        1
 <particle>      513  B*0               B*bar0            0  0     5.32480     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0      511       22
 <particle>      515  B*_20             B*_2bar0          0  0     5.83000     0.02000     0.05000  0.00000E+00  1
 <channel>   0.3000000    0      521     -211
 <channel>   0.1500000    0      511      111
 <channel>   0.1600000    0      523     -211
 <channel>   0.0800000    0      513      111
 <channel>   0.1300000    0      523     -211      111
 <channel>   0.0600000    0      513      211     -211
 <channel>   0.0800000    0      521     -211      111
 <channel>   0.0400000    0      511      211     -211
 <particle>      521  B+                B-                3  0     5.27890     0.00000     0.00000  4.62000E-01  1
 <channel>   0.0200000   42       12      -11     -421
 <channel>   0.0550000   42       12      -11     -423
 <channel>   0.0050000   42       12      -11   -10423
 <channel>   0.0050000   42       12      -11   -10421
 <channel>   0.0080000   42       12      -11   -20423
 <channel>   0.0120000   42       12      -11     -425
 <channel>   0.0200000   42       14      -13     -421
 <channel>   0.0550000   42       14      -13     -423
 <channel>   0.0050000   42       14      -13   -10423
 <channel>   0.0050000   42       14      -13   -10421
 <channel>   0.0080000   42       14      -13   -20423
 <channel>   0.0120000   42       14      -13     -425
 <channel>   0.0100000   42       16      -15     -421
 <channel>   0.0300000   42       16      -15     -423
 <channel>   0.0035000    0     -421      211
 <channel>   0.0110000    0     -421      213
 <channel>   0.0055000    0     -421    20213
 <channel>   0.0042000    0     -423      211
 <channel>   0.0090000    0     -423      213
 <channel>   0.0180000    0     -423    20213
 <channel>   0.0150000    0     -421      431
 <channel>   0.0185000    0     -421      433
 <channel>   0.0135000    0     -423      431
 <channel>   0.0250000    0     -423      433
 <channel>   0.0004000    0      441      321
 <channel>   0.0007000    0      441      323
 <channel>   0.0008000    0      443      321
 <channel>   0.0014000    0      443      323
 <channel>   0.0019000    0    20443      321
 <channel>   0.0025000    0    20443      323
 <channel>   0.4291000   43        2       -1       -4        2
 <channel>   0.0800000   13        2       -4       -1        2
 <channel>   0.0700000   13        4       -3       -4        2
 <channel>   0.0200000   13        4       -4       -3        2
 <channel>   0.0150000   42        2       -1       -2        2
 <channel>   0.0050000   42        4       -3       -2        2
 <particle>      523  B*+               B*-               3  0     5.32480     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0      521       22
 <particle>      525  B*_2+             B*_2-             3  0     5.83000     0.02000     0.05000  0.00000E+00  1
 <channel>   0.3000000    0      511      211
 <channel>   0.1500000    0      521      111
 <channel>   0.1600000    0      513      211
 <channel>   0.0800000    0      523      111
 <channel>   0.1300000    0      513      211      111
 <channel>   0.0600000    0      523      211     -211
 <channel>   0.0800000    0      511      211      111
 <channel>   0.0400000    0      521      211     -211
 <particle>      531  B_s0              B_sbar0           0  0     5.36930     0.00000     0.00000  4.83000E-01  1
 <channel>   0.0200000   42       12      -11     -431
 <channel>   0.0550000   42       12      -11     -433
 <channel>   0.0050000   42       12      -11   -10433
 <channel>   0.0050000   42       12      -11   -10431
 <channel>   0.0080000   42       12      -11   -20433
 <channel>   0.0120000   42       12      -11     -435
 <channel>   0.0200000   42       14      -13     -431
 <channel>   0.0550000   42       14      -13     -433
 <channel>   0.0050000   42       14      -13   -10433
 <channel>   0.0050000   42       14      -13   -10431
 <channel>   0.0080000   42       14      -13   -20433
 <channel>   0.0120000   42       14      -13     -435
 <channel>   0.0100000   42       16      -15     -431
 <channel>   0.0300000   42       16      -15     -433
 <channel>   0.0035000    0     -431      211
 <channel>   0.0110000    0     -431      213
 <channel>   0.0055000    0     -431    20213
 <channel>   0.0042000    0     -433      211
 <channel>   0.0090000    0     -433      213
 <channel>   0.0180000    0     -433    20213
 <channel>   0.0150000    0     -431      431
 <channel>   0.0185000    0     -431      433
 <channel>   0.0135000    0     -433      431
 <channel>   0.0250000    0     -433      433
 <channel>   0.0002000    0      441      221
 <channel>   0.0002000    0      441      331
 <channel>   0.0007000    0      441      333
 <channel>   0.0004000    0      443      221
 <channel>   0.0004000    0      443      331
 <channel>   0.0014000    0      443      333
 <channel>   0.0010000    0    20443      221
 <channel>   0.0009000    0    20443      331
 <channel>   0.0025000    0    20443      333
 <channel>   0.4291000   43        2       -1       -4        3
 <channel>   0.0800000   13        2       -4       -1        3
 <channel>   0.0700000   13        4       -3       -4        3
 <channel>   0.0200000   13        4       -4       -3        3
 <channel>   0.0150000   42        2       -1       -2        3
 <channel>   0.0050000   42        4       -3       -2        3
 <particle>      533  B*_s0             B*_sbar0          0  0     5.41630     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0      531       22
 <particle>      535  B*_2s0            B*_2sbar0         0  0     6.07000     0.02000     0.05000  0.00000E+00  1
 <channel>   0.3000000    0      521     -321
 <channel>   0.3000000    0      511     -311
 <channel>   0.2000000    0      523     -321
 <channel>   0.2000000    0      513     -311
 <particle>      541  B_c+              B_c-              3  0     6.59400     0.00000     0.00000  1.50000E-01  1
 <channel>   0.0470000    0       16      -15
 <channel>   0.1220000   11        4       -3
 <channel>   0.0060000   11        4       -1
 <channel>   0.0120000   42       12      -11      441
 <channel>   0.0350000   42       12      -11      443
 <channel>   0.0120000   42       14      -13      441
 <channel>   0.0350000   42       14      -13      443
 <channel>   0.0030000   42       16      -15      441
 <channel>   0.0070000   42       16      -15      443
 <channel>   0.1500000   42        2       -1       -4        4
 <channel>   0.0370000   42        2       -4       -1        4
 <channel>   0.0080000   42        2       -3       -4        4
 <channel>   0.0020000   42        2       -4       -3        4
 <channel>   0.0500000   42        4       -3       -4        4
 <channel>   0.0150000   42        4       -4       -3        4
 <channel>   0.0030000   42        4       -1       -4        4
 <channel>   0.0010000   42        4       -4       -1        4
 <channel>   0.0140000   42      -11       12      531
 <channel>   0.0420000   42      -11       12      533
 <channel>   0.0140000   42      -13       14      531
 <channel>   0.0420000   42      -13       14      533
 <channel>   0.2400000   42       -1        2        3       -5
 <channel>   0.0650000   42       -1        3        2       -5
 <channel>   0.0120000   42       -3        2        3       -5
 <channel>   0.0030000   42       -3        3        2       -5
 <channel>   0.0010000   42      -11       12      511
 <channel>   0.0020000   42      -11       12      513
 <channel>   0.0010000   42      -13       14      511
 <channel>   0.0020000   42      -13       14      513
 <channel>   0.0140000   42       -1        2        1       -5
 <channel>   0.0030000   42       -1        1        2       -5
 <particle>      543  B*_c+             B*_c-             3  0     6.60200     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0      541       22
 <particle>      545  B*_2c+            B*_2c-            3  0     7.35000     0.02000     0.05000  0.00000E+00  1
 <channel>   0.3000000    0      511      411
 <channel>   0.3000000    0      521      421
 <channel>   0.2000000    0      513      411
 <channel>   0.2000000    0      523      421
 <particle>      551  eta_b             void              0  0     9.40000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000   32       21       21
 <particle>      553  Upsilon           void              0  0     9.46030     0.00000     0.00000  0.00000E+00  1
 <channel>   0.0252000    0       11      -11
 <channel>   0.0248000    0       13      -13
 <channel>   0.0267000    0       15      -15
 <channel>   0.0150000   32        1       -1
 <channel>   0.0450000   32        2       -2
 <channel>   0.0150000   32        3       -3
 <channel>   0.0450000   32        4       -4
 <channel>   0.7743000   33       21       21       21
 <channel>   0.0290000   33       22       21       21
 <particle>      555  chi_2b            void              0  0     9.91320     0.00000     0.00000  0.00000E+00  1
 <channel>   0.2200000    0      553       22
 <channel>   0.7800000   32       21       21
 <particle>      990  pomeron           void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>     1103  dd_1              dd_1bar          -2 -1     0.77133     0.00000     0.00000  0.00000E+00  0
 <particle>     1114  Delta-            Deltabar+        -3  0     1.23400     0.12000     0.14000  0.00000E+00  1
 <channel>   1.0000000    0     2112     -211
 <particle>     2101  ud_0              ud_0bar           1 -1     0.57933     0.00000     0.00000  0.00000E+00  0
 <particle>     2103  ud_1              ud_1bar           1 -1     0.77133     0.00000     0.00000  0.00000E+00  0
 <particle>     2112  n0                nbar0             0  0     0.93957     0.00000     0.00000  0.00000E+00  0
 <particle>     2114  Delta0            Deltabar0         0  0     1.23300     0.12000     0.14000  0.00000E+00  1
 <channel>   0.3310000    0     2212     -211
 <channel>   0.6630000    0     2112      111
 <channel>   0.0060000    0     2112       22
 <particle>     2203  uu_1              uu_1bar           4 -1     0.77133     0.00000     0.00000  0.00000E+00  0
 <particle>     2212  p+                pbar-             3  0     0.93827     0.00000     0.00000  0.00000E+00  0
 <particle>     2214  Delta+            Deltabar-         3  0     1.23200     0.12000     0.14000  0.00000E+00  1
 <channel>   0.6630000    0     2212      111
 <channel>   0.3310000    0     2112      211
 <channel>   0.0060000    0     2212       22
 <particle>     2224  Delta++           Deltabar--        6  0     1.23100     0.12000     0.14000  0.00000E+00  1
 <channel>   1.0000000    0     2212      211
 <particle>     3101  sd_0              sd_0bar          -2 -1     0.80473     0.00000     0.00000  0.00000E+00  0
 <particle>     3103  sd_1              sd_1bar          -2 -1     0.92953     0.00000     0.00000  0.00000E+00  0
 <particle>     3112  Sigma-            Sigmabar+        -3  0     1.19744     0.00000     0.00000  4.43400E+01  1
 <channel>   0.9990000    0     2112     -211
 <channel>   0.0010000    0      -12       11     2112
 <particle>     3114  Sigma*-           Sigma*bar+       -3  0     1.38720     0.03940     0.04000  0.00000E+00  1
 <channel>   0.8800000    0     3122     -211
 <channel>   0.0600000    0     3212     -211
 <channel>   0.0600000    0     3112      111
 <particle>     3122  Lambda0           Lambdabar0        0  0     1.11568     0.00000     0.00000  7.88800E+01  1
 <channel>   0.6390000    0     2212     -211
 <channel>   0.3580000    0     2112      111
 <channel>   0.0020000    0     2112       22
 <channel>   0.0010000    0      -12       11     2212
 <particle>     3201  su_0              su_0bar           1 -1     0.80473     0.00000     0.00000  0.00000E+00  0
 <particle>     3203  su_1              su_1bar           1 -1     0.92953     0.00000     0.00000  0.00000E+00  0
 <particle>     3212  Sigma0            Sigmabar0         0  0     1.19255     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     3122       22
 <particle>     3214  Sigma*0           Sigma*bar0        0  0     1.38370     0.03600     0.03500  0.00000E+00  1
 <channel>   0.8800000    0     3122      111
 <channel>   0.0600000    0     3222     -211
 <channel>   0.0600000    0     3112      211
 <particle>     3222  Sigma+            Sigmabar-         3  0     1.18937     0.00000     0.00000  2.39600E+01  1
 <channel>   0.5160000    0     2212      111
 <channel>   0.4830000    0     2112      211
 <channel>   0.0010000    0     2212       22
 <particle>     3224  Sigma*+           Sigma*bar-        3  0     1.38280     0.03580     0.03500  0.00000E+00  1
 <channel>   0.8800000    0     3122      211
 <channel>   0.0600000    0     3222      111
 <channel>   0.0600000    0     3212      211
 <particle>     3303  ss_1              ss_1bar          -2 -1     1.09361     0.00000     0.00000  0.00000E+00  0
 <particle>     3312  Xi-               Xibar+           -3  0     1.32130     0.00000     0.00000  4.91000E+01  1
 <channel>   0.9988000    0     3122     -211
 <channel>   0.0001000    0     3112       22
 <channel>   0.0006000    0      -12       11     3122
 <channel>   0.0004000    0      -14       13     3122
 <channel>   0.0001000    0      -12       11     3212
 <particle>     3314  Xi*-              Xi*bar+          -3  0     1.53500     0.00990     0.05000  0.00000E+00  1
 <channel>   0.6670000    0     3322     -211
 <channel>   0.3330000    0     3312      111
 <particle>     3322  Xi0               Xibar0            0  0     1.31490     0.00000     0.00000  8.71000E+01  1
 <channel>   0.9954000    0     3122      111
 <channel>   0.0011000    0     3122       22
 <channel>   0.0035000    0     3212       22
 <particle>     3324  Xi*0              Xi*bar0           0  0     1.53180     0.00910     0.05000  0.00000E+00  1
 <channel>   0.3330000    0     3322      111
 <channel>   0.6670000    0     3312      211
 <particle>     3334  Omega-            Omegabar+        -3  0     1.67245     0.00000     0.00000  2.46000E+01  1
 <channel>   0.6760000    0     3122     -321
 <channel>   0.2340000    0     3322     -211
 <channel>   0.0850000    0     3312      111
 <channel>   0.0050000    0      -12       11     3322
 <particle>     4101  cd_0              cd_0bar           1 -1     1.96908     0.00000     0.00000  0.00000E+00  0
 <particle>     4103  cd_1              cd_1bar           1 -1     2.00808     0.00000     0.00000  0.00000E+00  0
 <particle>     4112  Sigma_c0          Sigma_cbar0       0  0     2.45210     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122     -211
 <particle>     4114  Sigma*_c0         Sigma*_cbar0      0  0     2.50000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122     -211
 <particle>     4122  Lambda_c+         Lambda_cbar-      3  0     2.28490     0.00000     0.00000  6.18000E-02  1
 <channel>   0.0180000   42      -11       12     3122
 <channel>   0.0050000   42      -11       12     3212
 <channel>   0.0050000   42      -11       12     3214
 <channel>   0.0030000   42      -11       12     2112
 <channel>   0.0020000   42      -11       12     2114
 <channel>   0.0060000   42      -11       12     2212     -211
 <channel>   0.0060000   42      -11       12     2112      111
 <channel>   0.0180000   42      -13       14     3122
 <channel>   0.0050000   42      -13       14     3212
 <channel>   0.0050000   42      -13       14     3214
 <channel>   0.0030000   42      -13       14     2112
 <channel>   0.0020000   42      -13       14     2114
 <channel>   0.0060000   42      -13       14     2212     -211
 <channel>   0.0060000   42      -13       14     2112      111
 <channel>   0.0066000    0     2224     -321
 <channel>   0.0250000    0     2224     -323
 <channel>   0.0160000    0     2212     -311
 <channel>   0.0088000    0     2212     -313
 <channel>   0.0050000    0     2214     -311
 <channel>   0.0050000    0     2214     -313
 <channel>   0.0058000    0     3122      211
 <channel>   0.0050000    0     3122      213
 <channel>   0.0055000    0     3212      211
 <channel>   0.0040000    0     3212      213
 <channel>   0.0040000    0     3214      211
 <channel>   0.0040000    0     3214      213
 <channel>   0.0040000    0     3222      111
 <channel>   0.0020000    0     3222      221
 <channel>   0.0020000    0     3222      331
 <channel>   0.0040000    0     3222      113
 <channel>   0.0040000    0     3222      223
 <channel>   0.0030000    0     3224      111
 <channel>   0.0020000    0     3224      221
 <channel>   0.0030000    0     3224      113
 <channel>   0.0030000    0     3224      223
 <channel>   0.0020000    0     3322      321
 <channel>   0.0020000    0     3322      323
 <channel>   0.0020000    0     3324      321
 <channel>   0.0010000    0     2224     -211
 <channel>   0.0010000    0     2224     -213
 <channel>   0.0020000    0     2212      111
 <channel>   0.0010000    0     2212      221
 <channel>   0.0010000    0     2212      331
 <channel>   0.0020000    0     2212      113
 <channel>   0.0020000    0     2212      223
 <channel>   0.0013000    0     2212      333
 <channel>   0.0018000    0     2212    10221
 <channel>   0.0010000    0     2214      111
 <channel>   0.0010000    0     2214      221
 <channel>   0.0010000    0     2214      331
 <channel>   0.0010000    0     2214      113
 <channel>   0.0010000    0     2214      223
 <channel>   0.0030000    0     2112      211
 <channel>   0.0030000    0     2112      213
 <channel>   0.0030000    0     2114      211
 <channel>   0.0030000    0     2114      213
 <channel>   0.0050000    0     3122      321
 <channel>   0.0050000    0     3122      323
 <channel>   0.0020000    0     3212      321
 <channel>   0.0020000    0     3212      323
 <channel>   0.0010000    0     3214      321
 <channel>   0.0010000    0     3214      323
 <channel>   0.0020000    0     3222      311
 <channel>   0.0020000    0     3222      313
 <channel>   0.0010000    0     3224      311
 <channel>   0.0010000    0     3224      313
 <channel>   0.2432000   13        2       -1        3     2101
 <channel>   0.0570000   13        2       -1        3     2103
 <channel>   0.0350000   13        2       -3        3     2101
 <channel>   0.0350000   13        2       -1        1     2101
 <channel>   0.1500000   13        3     2203
 <channel>   0.0750000   13        2     3201
 <channel>   0.0750000   13        2     3203
 <channel>   0.0300000   13        1     2203
 <channel>   0.0150000   13        2     2101
 <channel>   0.0150000   13        2     2103
 <particle>     4132  Xi_c0             Xi_cbar0          0  0     2.47030     0.00000     0.00000  2.90000E-02  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4201  cu_0              cu_0bar           4 -1     1.96908     0.00000     0.00000  0.00000E+00  0
 <particle>     4203  cu_1              cu_1bar           4 -1     2.00808     0.00000     0.00000  0.00000E+00  0
 <particle>     4212  Sigma_c+          Sigma_cbar-       3  0     2.45350     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122      111
 <particle>     4214  Sigma*_c+         Sigma*_cbar-      3  0     2.50000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122      111
 <particle>     4222  Sigma_c++         Sigma_cbar--      6  0     2.45290     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122      211
 <particle>     4224  Sigma*_c++        Sigma*_cbar--     6  0     2.50000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4122      211
 <particle>     4232  Xi_c+             Xi_cbar-          3  0     2.46560     0.00000     0.00000  1.06000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4301  cs_0              cs_0bar           1 -1     2.15432     0.00000     0.00000  0.00000E+00  0
 <particle>     4303  cs_1              cs_1bar           1 -1     2.17967     0.00000     0.00000  0.00000E+00  0
 <particle>     4312  Xi'_c0            Xi'_cbar0         0  0     2.55000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4132       22
 <particle>     4314  Xi*_c0            Xi*_cbar0         0  0     2.63000     0.00000     0.00000  0.00000E+00  1
 <channel>   0.5000000    0     4132      111
 <channel>   0.5000000    0     4132       22
 <particle>     4322  Xi'_c+            Xi'_cbar-         3  0     2.55000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4232       22
 <particle>     4324  Xi*_c+            Xi*_cbar-         3  0     2.63000     0.00000     0.00000  0.00000E+00  1
 <channel>   0.5000000    0     4232      111
 <channel>   0.5000000    0     4232       22
 <particle>     4332  Omega_c0          Omega_cbar0       0  0     2.70400     0.00000     0.00000  1.90000E-02  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4334  Omega*_c0         Omega*_cbar0      0  0     2.80000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     4332       22
 <particle>     4403  cc_1              cc_1bar           4 -1     3.27531     0.00000     0.00000  0.00000E+00  0
 <particle>     4412  Xi_cc+            Xi_ccbar-         3  0     3.59798     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4414  Xi*_cc+           Xi*_ccbar-        3  0     3.65648     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4422  Xi_cc++           Xi_ccbar--        6  0     3.59798     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4424  Xi*_cc++          Xi*_ccbar--       6  0     3.65648     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4432  Omega_cc+         Omega_ccbar-      3  0     3.78663     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4434  Omega*_cc+        Omega*_ccbar-     3  0     3.82466     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     4444  Omega*_ccc++      Omega*_cccbar-    6  0     4.91594     0.00000     0.00000  1.00000E-01  1
 <channel>   0.0800000   42      -11       12        3       81
 <channel>   0.0800000   42      -13       14        3       81
 <channel>   0.7600000   11        2       -1        3       81
 <channel>   0.0800000   11        2       -3        3       81
 <particle>     5101  bd_0              bd_0bar          -2 -1     5.38897     0.00000     0.00000  0.00000E+00  0
 <particle>     5103  bd_1              bd_1bar          -2 -1     5.40145     0.00000     0.00000  0.00000E+00  0
 <particle>     5112  Sigma_b-          Sigma_bbar+      -3  0     5.80000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122     -211
 <particle>     5114  Sigma*_b-         Sigma*_bbar+     -3  0     5.81000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122     -211
 <particle>     5122  Lambda_b0         Lambda_bbar0      0  0     5.64100     0.00000     0.00000  3.42000E-01  1
 <channel>   0.1050000   42      -12       11     4122
 <channel>   0.1050000   42      -14       13     4122
 <channel>   0.0400000   42      -16       15     4122
 <channel>   0.0077000    0     4122     -211
 <channel>   0.0200000    0     4122     -213
 <channel>   0.0235000    0     4122   -20213
 <channel>   0.0285000    0     4122     -431
 <channel>   0.0435000    0     4122     -433
 <channel>   0.0011000    0      441     3122
 <channel>   0.0022000    0      443     3122
 <channel>   0.0044000    0    20443     3122
 <channel>   0.4291000   43       -2        1        4     2101
 <channel>   0.0800000   13       -2        4        1     2101
 <channel>   0.0700000   13       -4        3        4     2101
 <channel>   0.0200000   13       -4        4        3     2101
 <channel>   0.0150000   42       -2        1        2     2101
 <channel>   0.0050000   42       -4        3        2     2101
 <particle>     5132  Xi_b-             Xi_bbar+         -3  0     5.84000     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5142  Xi_bc0            Xi_bcbar0         0  0     7.00575     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5201  bu_0              bu_0bar           1 -1     5.38897     0.00000     0.00000  0.00000E+00  0
 <particle>     5203  bu_1              bu_1bar           1 -1     5.40145     0.00000     0.00000  0.00000E+00  0
 <particle>     5212  Sigma_b0          Sigma_bbar0       0  0     5.80000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122      111
 <particle>     5214  Sigma*_b0         Sigma*_bbar0      0  0     5.81000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122      111
 <particle>     5222  Sigma_b+          Sigma_bbar-       3  0     5.80000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122      211
 <particle>     5224  Sigma*_b+         Sigma*_bbar-      3  0     5.81000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5122      211
 <particle>     5232  Xi_b0             Xi_bbar0          0  0     5.84000     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5242  Xi_bc+            Xi_bcbar-         3  0     7.00575     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5301  bs_0              bs_0bar          -2 -1     5.56725     0.00000     0.00000  0.00000E+00  0
 <particle>     5303  bs_1              bs_1bar          -2 -1     5.57536     0.00000     0.00000  0.00000E+00  0
 <particle>     5312  Xi'_b-            Xi'_bbar+        -3  0     5.96000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5132       22
 <particle>     5314  Xi*_b-            Xi*_bbar+        -3  0     5.97000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5132       22
 <particle>     5322  Xi'_b0            Xi'_bbar0         0  0     5.96000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5232       22
 <particle>     5324  Xi*_b0            Xi*_bbar0         0  0     5.97000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5232       22
 <particle>     5332  Omega_b-          Omega_bbar+      -3  0     6.12000     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5334  Omega*_b-         Omega*_bbar+     -3  0     6.13000     0.00000     0.00000  0.00000E+00  1
 <channel>   1.0000000    0     5332       22
 <particle>     5342  Omega_bc0         Omega_bcbar0      0  0     7.19099     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5401  bc_0              bc_0bar           1 -1     6.67143     0.00000     0.00000  0.00000E+00  0
 <particle>     5403  bc_1              bc_1bar           1 -1     6.67397     0.00000     0.00000  0.00000E+00  0
 <particle>     5412  Xi'_bc0           Xi'_bcbar0        0  0     7.03724     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5414  Xi*_bc0           Xi*_bcbar0        0  0     7.04850     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5422  Xi'_bc+           Xi'_bcbar-        3  0     7.03724     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5424  Xi*_bc+           Xi*_bcbar-        3  0     7.04850     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5432  Omega'_bc0        Omega'_bcba       0  0     7.21101     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5434  Omega*_bc0        Omega*_bcbar0     0  0     7.21900     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5442  Omega_bcc+        Omega_bccbar-     3  0     8.30945     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5444  Omega*_bcc+       Omega*_bccbar-    3  0     8.31325     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5503  bb_1              bb_1bar          -2 -1    10.07354     0.00000     0.00000  0.00000E+00  0
 <particle>     5512  Xi_bb-            Xi_bbbar+        -3  0    10.42272     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5514  Xi*_bb-           Xi*_bbbar+       -3  0    10.44144     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5522  Xi_bb0            Xi_bbbar0         0  0    10.42272     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5524  Xi*_bb0           Xi*_bbbar0        0  0    10.44144     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5532  Omega_bb-         Omega_bbbar+     -3  0    10.60209     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5534  Omega*_bb-        Omega*_bbbar+    -3  0    10.61426     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5542  Omega_bbc0        Omega_bbcbar0     0  0    11.70767     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5544  Omega*_bbc0       Omega*_bbcbar0    0  0    11.71147     0.00000     0.00000  3.87000E-01  1
 <channel>   0.1050000   42      -12       11        4       81
 <channel>   0.1050000   42      -14       13        4       81
 <channel>   0.0400000   42      -16       15        4       81
 <channel>   0.5000000   42       -2        1        4       81
 <channel>   0.0800000   42       -2        4        1       81
 <channel>   0.1400000   42       -4        3        4       81
 <channel>   0.0100000   42       -4        4        3       81
 <channel>   0.0150000   42       -2        1        2       81
 <channel>   0.0050000   42       -4        3        2       81
 <particle>     5554  Omega*_bbb-       Omega*_bbbbar+   -3  0    15.11061     0.00000     0.00000  3.87000E-01  1
 <particle>    10111  a_00              void              0  0     0.98350     0.06000     0.05000  0.00000E+00  1
 <channel>   1.0000000    0      221      111
 <particle>    10113  b_10              void              0  0     1.23100     0.14200     0.25000  0.00000E+00  1
 <channel>   1.0000000    0      223      111
 <particle>    10211  a_0+              a_0-              3  0     0.98350     0.06000     0.05000  0.00000E+00  1
 <channel>   1.0000000    0      221      211
 <particle>    10213  b_1+              b_1-              3  0     1.23100     0.14200     0.25000  0.00000E+00  1
 <channel>   1.0000000    0      223      211
 <particle>    10221  f_0               void              0  0     1.00000     0.00000     0.00000  0.00000E+00  1
 <channel>   0.5200000    0      211     -211
 <channel>   0.2600000    0      111      111
 <channel>   0.1100000    0      321     -321
 <channel>   0.0550000    0      130      130
 <channel>   0.0550000    0      310      310
 <particle>    10223  h_1               void              0  0     1.17000     0.36000     0.20000  0.00000E+00  1
 <channel>   0.3330000    0      213     -211
 <channel>   0.3340000    0      113      111
 <channel>   0.3330000    0     -213      211
 <particle>    10311  K*_00             K*_0bar0          0  0     1.42900     0.28700     0.40000  0.00000E+00  1
 <channel>   0.6670000    0      321     -211
 <channel>   0.3330000    0      311      111
 <particle>    10313  K_10              K_1bar0           0  0     1.29000     0.09000     0.00500  0.00000E+00  1
 <channel>   0.2800000    0      321     -213
 <channel>   0.1400000    0      311      113
 <channel>   0.3130000    0      323     -211
 <channel>   0.1570000    0      313      111
 <channel>   0.1100000    0      311      223
 <particle>    10321  K*_0+             K*_0-             3  0     1.42900     0.28700     0.40000  0.00000E+00  1
 <channel>   0.6670000    0      311      211
 <channel>   0.3330000    0      321      111
 <particle>    10323  K_1+              K_1-              3  0     1.29000     0.09000     0.01000  0.00000E+00  1
 <channel>   0.2800000    0      311      213
 <channel>   0.1400000    0      321      113
 <channel>   0.3130000    0      313      211
 <channel>   0.1570000    0      323      111
 <channel>   0.1100000    0      321      223
 <particle>    10331  f'_0              void              0  0     1.40000     0.25000     0.35000  0.00000E+00  1
 <channel>   0.3600000    0      211     -211
 <channel>   0.1800000    0      111      111
 <channel>   0.0300000    0      321     -321
 <channel>   0.0150000    0      130      130
 <channel>   0.0150000    0      310      310
 <channel>   0.2000000    0      211     -211      211     -211
 <channel>   0.2000000    0      211     -211      111      111
 <particle>    10333  h'_1              void              0  0     1.40000     0.08000     0.00100  0.00000E+00  1
 <channel>   0.2500000    0      313     -311
 <channel>   0.2500000    0     -313      311
 <channel>   0.2500000    0      323     -321
 <channel>   0.2500000    0     -323      321
 <particle>    10411  D*_0+             D*_0-             3  0     2.27200     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      421      211
 <channel>   0.3330000    0      411      111
 <particle>    10413  D_1+              D_1-              3  0     2.42400     0.02000     0.08000  0.00000E+00  1
 <channel>   0.6670000    0      423      211
 <channel>   0.3330000    0      413      111
 <particle>    10421  D*_00             D*_0bar0          0  0     2.27200     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      411     -211
 <channel>   0.3330000    0      421      111
 <particle>    10423  D_10              D_1bar0           0  0     2.42400     0.02000     0.08000  0.00000E+00  1
 <channel>   0.6670000    0      413     -211
 <channel>   0.3330000    0      423      111
 <particle>    10431  D*_0s+            D*_0s-            3  0     2.50000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      411      311
 <channel>   0.5000000    0      421      321
 <particle>    10433  D_1s+             D_1s-             3  0     2.53600     0.00000     0.00000  0.00000E+00  1
 <channel>   0.5000000    0      423      321
 <channel>   0.5000000    0      413      311
 <particle>    10441  chi_0c            void              0  0     3.41510     0.01400     0.05000  0.00000E+00  1
 <channel>   0.0070000    0      443       22
 <channel>   0.9930000   12       82      -82
 <particle>    10443  h_1c              void              0  0     3.46000     0.01000     0.02000  0.00000E+00  1
 <channel>   1.0000000   12       82      -82
 <particle>    10511  B*_00             B*_0bar0          0  0     5.68000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      521     -211
 <channel>   0.3330000    0      511      111
 <particle>    10513  B_10              B_1bar0           0  0     5.73000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      523     -211
 <channel>   0.3330000    0      513      111
 <particle>    10521  B*_0+             B*_0-             3  0     5.68000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      511      211
 <channel>   0.3330000    0      521      111
 <particle>    10523  B_1+              B_1-              3  0     5.73000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      513      211
 <channel>   0.3330000    0      523      111
 <particle>    10531  B*_0s0            B*_0sbar0         0  0     5.92000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      521     -321
 <channel>   0.5000000    0      511     -311
 <particle>    10533  B_1s0             B_1sbar0          0  0     5.97000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      523     -321
 <channel>   0.5000000    0      513     -311
 <particle>    10541  B*_0c+            B*_0c-            3  0     7.25000     0.05000     0.05000  0.00000E+00  1
 <channel>   0.5000000    0      511      411
 <channel>   0.5000000    0      521      421
 <particle>    10543  B_1c+             B_1c-             3  0     7.30000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      513      411
 <channel>   0.5000000    0      523      421
 <particle>    10551  chi_0b            void              0  0     9.85980     0.00000     0.00000  0.00000E+00  1
 <channel>   0.0200000    0      553       22
 <channel>   0.9800000   32       21       21
 <particle>    10553  h_1b              void              0  0     9.87500     0.01000     0.02000  0.00000E+00  1
 <channel>   1.0000000   32       21       21
 <particle>    20113  a_10              void              0  0     1.23000     0.40000     0.30000  0.00000E+00  1
 <channel>   0.5000000    0      213     -211
 <channel>   0.5000000    0     -213      211
 <particle>    20213  a_1+              a_1-              3  0     1.23000     0.40000     0.30000  0.00000E+00  1
 <channel>   0.5000000    0      113      211
 <channel>   0.5000000    0      213      111
 <particle>    20223  f_1               void              0  0     1.28200     0.02500     0.05000  0.00000E+00  1
 <channel>   0.1460000    0    10211     -211
 <channel>   0.1460000    0    10111      111
 <channel>   0.1460000    0   -10211      211
 <channel>   0.0500000    0      221      211     -211
 <channel>   0.0500000    0      221      111      111
 <channel>   0.0500000    0      213     -211      111
 <channel>   0.1500000    0      113      211     -211
 <channel>   0.0500000    0      113      111      111
 <channel>   0.0500000    0     -213      211      111
 <channel>   0.0240000    0      321     -321      111
 <channel>   0.0240000    0      321     -311     -211
 <channel>   0.0240000    0      311     -311      111
 <channel>   0.0240000    0      311     -321      211
 <channel>   0.0660000    0      113       22
 <particle>    20313  K*_10             K*_1bar0          0  0     1.40200     0.17400     0.30000  0.00000E+00  1
 <channel>   0.6670000    0      323     -211
 <channel>   0.3330000    0      313      111
 <particle>    20323  K*_1+             K*_1-             3  0     1.40200     0.17400     0.30000  0.00000E+00  1
 <channel>   0.6670000    0      313      211
 <channel>   0.3330000    0      323      111
 <particle>    20333  f'_1              void              0  0     1.42700     0.05300     0.02000  0.00000E+00  1
 <channel>   0.2500000    0      313     -311
 <channel>   0.2500000    0     -313      311
 <channel>   0.2500000    0      323     -321
 <channel>   0.2500000    0     -323      321
 <particle>    20413  D*_1+             D*_1-             3  0     2.37200     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      423      211
 <channel>   0.3330000    0      413      111
 <particle>    20423  D*_10             D*_1bar0          0  0     2.37200     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      413     -211
 <channel>   0.3330000    0      423      111
 <particle>    20433  D*_1s+            D*_1s-            3  0     2.56000     0.05000     0.03000  0.00000E+00  1
 <channel>   0.5000000    0      423      321
 <channel>   0.5000000    0      413      311
 <particle>    20443  chi_1c            void              0  0     3.51060     0.00090     0.00100  0.00000E+00  1
 <channel>   0.2730000    0      443       22
 <channel>   0.7270000   12       82      -82
 <particle>    20513  B*_10             B*_1bar0          0  0     5.78000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      523     -211
 <channel>   0.3330000    0      513      111
 <particle>    20523  B*_1+             B*_1-             3  0     5.78000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.6670000    0      513      211
 <channel>   0.3330000    0      523      111
 <particle>    20533  B*_1s0            B*_1sbar0         0  0     6.02000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      523     -321
 <channel>   0.5000000    0      513     -311
 <particle>    20543  B*_1c+            B*_1c-            3  0     7.30000     0.05000     0.10000  0.00000E+00  1
 <channel>   0.5000000    0      513      411
 <channel>   0.5000000    0      523      421
 <particle>    20553  chi_1b            void              0  0     9.89190     0.00000     0.00000  0.00000E+00  1
 <channel>   0.3500000    0      553       22
 <channel>   0.6500000   32       21       21
 <particle>   100443  psi'              void              0  0     3.68600     0.00000     0.00000  0.00000E+00  1
 <channel>   0.0083000    0       11      -11
 <channel>   0.0083000    0       13      -13
 <channel>   0.1866000   12       82      -82
 <channel>   0.3240000    0      443      211     -211
 <channel>   0.1840000    0      443      111      111
 <channel>   0.0270000    0      443      221
 <channel>   0.0010000    0      443      111
 <channel>   0.0930000    0    10441       22
 <channel>   0.0870000    0    20443       22
 <channel>   0.0780000    0      445       22
 <channel>   0.0028000    0      441       22
 <particle>   100553  Upsilon'          void              0  0    10.02330     0.00000     0.00000  0.00000E+00  1
 <channel>   0.0140000    0       11      -11
 <channel>   0.0140000    0       13      -13
 <channel>   0.0140000    0       15      -15
 <channel>   0.0080000   32        1       -1
 <channel>   0.0240000   32        2       -2
 <channel>   0.0080000   32        3       -3
 <channel>   0.0240000   32        4       -4
 <channel>   0.4250000   33       21       21       21
 <channel>   0.0200000   33       22       21       21
 <channel>   0.1850000    0      553      211     -211
 <channel>   0.0880000    0      553      111      111
 <channel>   0.0430000    0    10551       22
 <channel>   0.0670000    0    20553       22
 <channel>   0.0660000    0      555       22
 <particle>  1000001  ~d_L              ~d_Lbar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000002  ~u_L              ~u_Lbar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000003  ~s_L              ~s_Lbar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000004  ~c_L              ~c_Lbar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000005  ~b_1              ~b_1bar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000006  ~t_1              ~t_1bar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000011  ~e_L-             ~e_L+            -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000012  ~nu_eL            ~nu_eLbar         0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000013  ~mu_L-            ~mu_L+           -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000014  ~nu_muL           ~nu_muLbar        0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000015  ~tau_1-           ~tau_1+          -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000016  ~nu_tauL          ~nu_tauLbar       0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000021  ~g                void              0  2   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000022  ~chi_10           void              0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000023  ~chi_20           void              0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000024  ~chi_1+           ~chi_1-           3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000025  ~chi_30           void              0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000035  ~chi_40           void              0  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000037  ~chi_2+           ~chi_2-           3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  1000039  ~Gravitino        void              0  0   500.00000     0.00000     0.00001  0.00000E+00  0
 <particle>  2000001  ~d_R              ~d_Rbar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000002  ~u_R              ~u_Rbar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000003  ~s_R              ~s_Rbar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000004  ~c_R              ~c_Rbar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000005  ~b_2              ~b_2bar          -1  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000006  ~t_2              ~t_2bar           2  1   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000011  ~e_R-             ~e_R+            -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000012  ~nu_eR            ~nu_eRbar         0  0   500.00000     0.00000     0.00001  0.00000E+00  0
 <particle>  2000013  ~mu_R-            ~mu_R+           -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000014  ~nu_muR           ~nu_muRbar        0  0   500.00000     0.00000     0.00001  0.00000E+00  0
 <particle>  2000015  ~tau_2-           ~tau_2+          -3  0   500.00000     1.00000    10.00000  0.00000E+00  1
 <particle>  2000016  ~nu_tauR          ~nu_tauRbar       0  0   500.00000     0.00000     0.00001  0.00000E+00  0
 <particle>  3000111  pi_tc0            void              0  0   110.00000     0.02911     0.29108  0.00000E+00  1
 <particle>  3000211  pi_tc+            pi_tc-            3  0   110.00000     0.01741     0.17412  0.00000E+00  1
 <particle>  3000221  pi'_tc0           void              0  0   110.00000     0.04536     0.45362  0.00000E+00  1
 <particle>  3000331  eta_tc0           void              0  2   350.00000     0.09511     0.95114  0.00000E+00  1
 <particle>  3000113  rho_tc0           void              0  0   210.00000     0.86860     8.68604  0.00000E+00  1
 <particle>  3000213  rho_tc+           rho_tc-           3  0   210.00000     0.62395     6.23946  0.00000E+00  1
 <particle>  3000223  omega_tc          void              0  0   210.00000     0.19192     1.91923  0.00000E+00  1
 <particle>  3100021  V8_tc             void              0  2   500.00000   123.27638   450.00000  0.00000E+00  1
 <particle>  3100111  pi_22_1_tc        void              0  0   125.00000     0.02296     0.22959  0.00000E+00  1
 <particle>  3200111  pi_22_8_tc        void              0  2   250.00000     0.18886     1.88863  0.00000E+00  1
 <particle>  3100113  rho_11_tc         void              0  2   400.00000    23.26819   232.68185  0.00000E+00  1
 <particle>  3200113  rho_12_tc         void              0  2   350.00000     2.86306    28.63059  0.00000E+00  1
 <particle>  3300113  rho_21_tc         void              0  2   350.00000     0.00000     0.00000  0.00000E+00  1
 <particle>  3400113  rho_22_tc         void              0  2   300.00000     3.45903    34.59032  0.00000E+00  1
 <particle>  4000001  d*                d*bar            -1  1   400.00000     2.59359    25.93594  0.00000E+00  1
 <particle>  4000002  u*                u*bar             2  1   400.00000     2.59687    25.96873  0.00000E+00  1
 <particle>  4000011  e*-               e*bar+           -3  0   400.00000     0.42896     4.28961  0.00000E+00  1
 <particle>  4000012  nu*_e0            nu*_ebar0         0  0   400.00000     0.41912     4.19124  0.00000E+00  1
 <particle>  5000039  Graviton*         void              0  0  1000.00000     0.14153     1.41528  0.00000E+00  1
 <particle>  9900012  nu_Re             void              0  0   500.00000     0.00098     0.00977  0.00000E+00  1
 <particle>  9900014  nu_Rmu            void              0  0   500.00000     0.00098     0.00976  0.00000E+00  1
 <particle>  9900016  nu_Rtau           void              0  0   500.00000     0.00097     0.00973  0.00000E+00  1
 <particle>  9900023  Z_R0              void              0  0  1200.00000    26.72450   267.24501  0.00000E+00  1
 <particle>  9900024  W_R+              W_R-              3  0   750.00000    21.74916   217.49162  0.00000E+00  1
 <particle>  9900041  H_L++             H_L--             6  0   200.00000     0.88159     8.81592  0.00000E+00  1
 <particle>  9900042  H_R++             H_R--             6  0   200.00000     0.88001     8.80013  0.00000E+00  1
 <particle>  9900110  rho_diff0         void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9900210  pi_diffr+         pi_diffr-         3  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9900220  omega_di          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9900330  phi_diff          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9900440  J/psi_di          void              0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9902110  n_diffr0          n_diffrbar0       0  0     0.00000     0.00000     0.00000  0.00000E+00  0
 <particle>  9902210  p_diffr+          p_diffrbar-       3  0     0.00000     0.00000     0.00000  0.00000E+00  0

---------------------------------------------------------------------- 

Copyright  2005 Torbjrn Sjstrand
